"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBottomSpace = exports.navBarUnlessStatusHeight = exports.navBarHeight = exports.navigationBarHeight = exports.statusBarHeight = exports.ifIphoneX = exports.scaleSize = exports.isIphoneX = exports.setConfig = exports.screenH = exports.screenW = exports.onePixel = void 0;
// @ts-ignore
var react_native_1 = require("react-native");
var APPBAR_HEIGHT = react_native_1.Platform.OS === 'ios' ? 44 : 56;
var STATUSBAR_HEIGHT = react_native_1.Platform.OS === 'ios' ? 20 : 0;
var HEADER_HEIGHT = APPBAR_HEIGHT + STATUSBAR_HEIGHT;
var getResolvedDimensions = function () {
    var _a = react_native_1.Dimensions.get('window'), width = _a.width, height = _a.height;
    if (width === 0 && height === 0)
        return react_native_1.Dimensions.get('screen');
    return { width: width, height: height };
};
var _a = getResolvedDimensions(), width = _a.width, height = _a.height;
exports.onePixel = 1 / react_native_1.PixelRatio.get();
exports.screenW = Math.min(width, height);
exports.screenH = Math.max(width, height);
// 以iphone6为基准,如果以其他尺寸为基准的话,请修改下面的defaultWidth和defaultHeight为对应尺寸即可
var defaultWidth = 375;
// 缩放比例
var _scaleWidth = exports.screenW / defaultWidth;
/**
 * 修改配置
 * @param baseWidth
 */
function setConfig(_a) {
    var baseWidth = _a.baseWidth;
    _scaleWidth = exports.screenW / baseWidth;
}
exports.setConfig = setConfig;
/**
 * 判断是否为iphoneX
 * @returns {boolean}
 */
var isIphoneX = function () {
    var dimen = react_native_1.Dimensions.get('window');
    return (react_native_1.Platform.OS === 'ios'
        && !react_native_1.Platform.isPad
        && !react_native_1.Platform.isTVOS
        && (dimen.height === 780
            || dimen.width === 780
            || dimen.height === 812 || dimen.width === 812
            || dimen.height === 844 || dimen.width === 844
            || dimen.height === 896 || dimen.width === 896
            || dimen.height === 926 || dimen.width === 926));
};
exports.isIphoneX = isIphoneX;
/**
 * 屏幕适配, 缩放size , 默认根据宽度适配，纵向也可以使用此方法
 * @param size 设计图的尺寸
 * @returns {number}
 */
function scaleSize(size) {
    // 如果是 "1%" 样式 直接返回不进行换算
    if (isNaN(size)) {
        return size;
    }
    // 如果size不为0 并且 小于一个像素 那么就返回一个像素 处理负数 - 0.1  -一个像素
    if (size && Math.abs(size) < exports.onePixel) {
        return size < 0 ? -exports.onePixel : exports.onePixel;
    }
    // ok  进行换算 基准宽度 375
    var pixel = react_native_1.PixelRatio.getPixelSizeForLayoutSize(size) * _scaleWidth;
    return Math.floor(pixel) * exports.onePixel;
}
exports.scaleSize = scaleSize;
/**
 * 根据是否是iPhoneX返回不同的样式
 * @param iphoneXStyle
 * @param iosStyle
 * @param androidStyle
 * @returns {*}
 */
function ifIphoneX(iphoneXStyle, iosStyle, androidStyle) {
    if (iosStyle === void 0) { iosStyle = {}; }
    if (exports.isIphoneX()) {
        return iphoneXStyle;
    }
    else if (react_native_1.Platform.OS === 'ios') {
        return iosStyle;
    }
    else {
        if (androidStyle)
            return androidStyle;
        return iosStyle;
    }
}
exports.ifIphoneX = ifIphoneX;
/**
 * 状态栏高度
 */
function statusBarHeight() {
    if (react_native_1.Platform.OS === 'ios') {
        if (exports.isIphoneX()) {
            return 44;
        }
        return 20;
    }
    else {
        // 自动获取导航栏高度，官方参考 720 * 1280 尺寸为 48
        return react_native_1.StatusBar.currentHeight;
    }
}
exports.statusBarHeight = statusBarHeight;
/**
 * 常规导航栏高度（包含状态栏）
 */
function navigationBarHeight() {
    if (react_native_1.Platform.OS === 'ios') {
        if (exports.isIphoneX()) {
            return 88;
        }
        return 64;
    }
    else {
        return HEADER_HEIGHT;
    }
}
exports.navigationBarHeight = navigationBarHeight;
/**
 * 状态栏加导航栏的高度
 * @returns {*}
 */
function navBarHeight() {
    if (react_native_1.Platform.OS === 'ios') {
        if (exports.isIphoneX()) {
            return 44 + 44;
        }
        return 20 + 44;
    }
    else {
        // 自动获取导航栏高度，官方参考 720 * 1280 尺寸为 48
        return react_native_1.StatusBar.currentHeight + 54;
    }
}
exports.navBarHeight = navBarHeight;
/**
 * 导航栏高度(不包含状态栏)
 * @returns {*}
 */
function navBarUnlessStatusHeight() {
    return APPBAR_HEIGHT;
}
exports.navBarUnlessStatusHeight = navBarUnlessStatusHeight;
/**
 * 获取底部边距
 */
function getBottomSpace() {
    return exports.isIphoneX() ? 34 : 0;
}
exports.getBottomSpace = getBottomSpace;
